@@ -2,12 +2,6 @@
 # -*- coding: utf-8 -*-
 HELPER_SETTINGS = {
     'INSTALLED_APPS': [],
-    'CMS_LANGUAGES': {
-        1: [{
-            'code': 'en',
-            'name': 'English',
-        }]
-    },
     'LANGUAGE_CODE': 'en',
     'ALLOWED_HOSTS': ['localhost'],
 }
@@ -15,7 +9,7 @@ HELPER_SETTINGS = {
 
 def run():
     from djangocms_helper import runner
-    runner.cms('aldryn_django')
+    runner.run('aldryn_django')
 
 
 if __name__ == '__main__':
